@@ -73,7 +73,7 @@ def titleSummaryMaker(csv):
     column = ["brand", "title_summary_temp", "title_summary"]
     pool.columns = column
 
-    return pool[['title_summary_temp', 'title_summary']]
+    return pool
 
 
 def csvImporter(csv_folder, csv_folder_encoding, csv_folder_cleaned, db_table_name, column_name):
@@ -100,7 +100,7 @@ def addPoolColumn(dataframe, keyword_pool):
 
     dataframe['title_summary_temp'] = dataframe['title_summary_temp'].apply(lambda x: max(x, key=lambda y: len(y)) if x else '')
 
-    final_df = pd.merge(dataframe, title_mapping, how='left', on='title_summary_temp')
+    final_df = pd.merge(dataframe, title_mapping, how='left', on=["brand", "title_summary_temp"])
 
     return final_df
 
@@ -169,7 +169,7 @@ def keywordCheck(csv_folder_cleaned, pool_check_folder, keyword_pool, column_nam
 
     fileList = os.listdir(csv_folder_cleaned)
     for i in range(len(fileList)):
-        dataframe = pd.read_csv(csv_folder_cleaned + "\\" + fileList[i], sep=',', engine='c', encoding='latin-1')
+        dataframe = pd.read_csv(csv_folder_cleaned + "\\" + fileList[i], sep=',', engine='c', encoding='latin-1', low_memory=False)
         dataframe.columns = column_name
         
         dataframe.insert(0, "file_name", fileList[i][:-4], True)
@@ -185,7 +185,7 @@ def keywordCheck(csv_folder_cleaned, pool_check_folder, keyword_pool, column_nam
              
         check_frame['title_summary_temp'] = check_frame['title_summary_list'].apply(lambda x: max(x, key=lambda y: len(y)) if x else '')
         
-        final_df = pd.merge(check_frame, title_mapping, how='left', on='title_summary_temp')
+        final_df = pd.merge(check_frame, title_mapping, how='left', on=["brand", "title_summary_temp"])
 
         final_df.to_csv(pool_check_folder + "\\Keyword_Check_" + str(time.strftime('%Y%m%d-%H%M%S', time.localtime())) + "_" + fileList[i], sep=',', na_rep='', encoding='utf-8-sig', index = False)
         print("Keyword_Check_" + fileList[i] + " is created")
